@@ -31,7 +31,7 @@ class InvalidCodeError(APIError):
     code = 'invalid_code'
 
 
-class JWTDecodError(APIError):
+class JWTDecodeError(APIError):
     status_code = 400
     detail = 'jwt decode error'
     code = 'invalid_jwt'
